@@ -12,6 +12,11 @@ type Printer interface {
 	PrintResults(matchingNodes *list.List) error
 	PrintedAnything() bool
 	SetPrintLeadingSeperator(bool)
+
+	SetPreamble(reader io.Reader)
+
+	//e.g. when given a front-matter doc, like jekyll
+	SetAppendix(reader io.Reader)
 }
 
 type resultsPrinter struct {
@@ -26,6 +31,8 @@ type resultsPrinter struct {
 	previousFileIndex  int
 	printedMatches     bool
 	treeNavigator      DataTreeNavigator
+	preambleReader     io.Reader
+	appendixReader     io.Reader
 }
 
 func NewPrinter(writer io.Writer, outputToJSON bool, unwrapScalar bool, colorsEnabled bool, indent int, printDocSeparators bool) Printer {
@@ -48,6 +55,14 @@ func (p *resultsPrinter) SetPrintLeadingSeperator(printLeadingSeperator bool) {
 	}
 }
 
+func (p *resultsPrinter) SetPreamble(reader io.Reader) {
+	p.preambleReader = reader
+}
+
+func (p *resultsPrinter) SetAppendix(reader io.Reader) {
+	p.appendixReader = reader
+}
+
 func (p *resultsPrinter) PrintedAnything() bool {
 	return p.printedMatches
 }
@@ -95,6 +110,14 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 	bufferedWriter := bufio.NewWriter(p.writer)
 	defer p.safelyFlush(bufferedWriter)
 
+	if p.preambleReader != nil && !p.outputToJSON {
+		log.Debug("Piping preamble reader...")
+		_, err := io.Copy(bufferedWriter, p.preambleReader)
+		if err != nil {
+			return err
+		}
+	}
+
 	if matchingNodes.Len() == 0 {
 		log.Debug("no matching results, nothing to print")
 		return nil
@@ -123,5 +146,14 @@ func (p *resultsPrinter) PrintResults(matchingNodes *list.List) error {
 		p.previousDocIndex = mappedDoc.Document
 	}
 
+	if p.appendixReader != nil && !p.outputToJSON {
+		log.Debug("Piping appendix reader...")
+		betterReader := bufio.NewReader(p.appendixReader)
+		_, err := io.Copy(bufferedWriter, betterReader)
+		if err != nil {
+			return err
+		}
+	}
+
 	return nil
 }
